@@ -3,11 +3,13 @@ Various constants for psd_tools
 """
 from enum import Enum, IntEnum, auto
 
+
 class CompatibilityMode(Enum):
     """
     Compatibility modes that describe how compositing and
     layer control should attempt to behave.
     """
+
     PHOTOSHOP = auto()
     PAINT_TOOL_SAI = auto()
     CLIP_STUDIO_PAINT = auto()
@@ -16,10 +18,12 @@ class CompatibilityMode(Enum):
 
     DEFAULT = PHOTOSHOP
 
+
 class ColorMode(IntEnum):
     """
     Color mode.
     """
+
     BITMAP = 0
     GRAYSCALE = 1
     INDEXED = 2
@@ -47,6 +51,7 @@ class ColorSpaceID(IntEnum):
     """
     Color space types.
     """
+
     RGB = 0
     HSB = 1
     CMYK = 2
@@ -64,6 +69,7 @@ class Resource(IntEnum):
      * PLUGIN_RESOURCES_10 to PLUGIN_RESOURCES_989 corresponding to
         4010 - 4989
     """
+
     OBSOLETE1 = 1000
     MAC_PRINT_MANAGER_INFO = 1001
     MAC_PAGE_FORMAT_INFO = 1002
@@ -212,15 +218,17 @@ class LinkedLayerType(bytes, Enum):
     """
     Linked layer types.
     """
-    DATA = b'liFD'
-    EXTERNAL = b'liFE'
-    ALIAS = b'liFA'
+
+    DATA = b"liFD"
+    EXTERNAL = b"liFE"
+    ALIAS = b"liFA"
 
 
 class ChannelID(IntEnum):
     """
     Channel types.
     """
+
     CHANNEL_0 = 0  # Red, Cyan, Gray, ...
     CHANNEL_1 = 1  # Green, Magenta, ...
     CHANNEL_2 = 2  # Blue, Yellow, ...
@@ -238,6 +246,7 @@ class ChannelID(IntEnum):
 
 class Clipping(IntEnum):
     """Clipping."""
+
     BASE = 0
     NON_BASE = 1
 
@@ -246,38 +255,40 @@ class BlendMode(bytes, Enum):
     """
     Blend modes.
     """
-    PASS_THROUGH = b'pass'
-    NORMAL = b'norm'
-    DISSOLVE = b'diss'
-    DARKEN = b'dark'
-    MULTIPLY = b'mul '
-    COLOR_BURN = b'idiv'
-    LINEAR_BURN = b'lbrn'
-    DARKER_COLOR = b'dkCl'
-    LIGHTEN = b'lite'
-    SCREEN = b'scrn'
-    COLOR_DODGE = b'div '
-    LINEAR_DODGE = b'lddg'
-    LIGHTER_COLOR = b'lgCl'
-    OVERLAY = b'over'
-    SOFT_LIGHT = b'sLit'
-    HARD_LIGHT = b'hLit'
-    VIVID_LIGHT = b'vLit'
-    LINEAR_LIGHT = b'lLit'
-    PIN_LIGHT = b'pLit'
-    HARD_MIX = b'hMix'
-    DIFFERENCE = b'diff'
-    EXCLUSION = b'smud'
-    SUBTRACT = b'fsub'
-    DIVIDE = b'fdiv'
-    HUE = b'hue '
-    SATURATION = b'sat '
-    COLOR = b'colr'
-    LUMINOSITY = b'lum '
+
+    PASS_THROUGH = b"pass"
+    NORMAL = b"norm"
+    DISSOLVE = b"diss"
+    DARKEN = b"dark"
+    MULTIPLY = b"mul "
+    COLOR_BURN = b"idiv"
+    LINEAR_BURN = b"lbrn"
+    DARKER_COLOR = b"dkCl"
+    LIGHTEN = b"lite"
+    SCREEN = b"scrn"
+    COLOR_DODGE = b"div "
+    LINEAR_DODGE = b"lddg"
+    LIGHTER_COLOR = b"lgCl"
+    OVERLAY = b"over"
+    SOFT_LIGHT = b"sLit"
+    HARD_LIGHT = b"hLit"
+    VIVID_LIGHT = b"vLit"
+    LINEAR_LIGHT = b"lLit"
+    PIN_LIGHT = b"pLit"
+    HARD_MIX = b"hMix"
+    DIFFERENCE = b"diff"
+    EXCLUSION = b"smud"
+    SUBTRACT = b"fsub"
+    DIVIDE = b"fdiv"
+    HUE = b"hue "
+    SATURATION = b"sat "
+    COLOR = b"colr"
+    LUMINOSITY = b"lum "
 
 
 class GlobalLayerMaskKind(IntEnum):
     """Global layer mask kind."""
+
     COLOR_SELECTED = 0
     COLOR_PROTECTED = 1
     PER_LAYER = 128
@@ -291,6 +302,7 @@ class Compression(IntEnum):
     Compression. 0 = Raw Data, 1 = RLE compressed, 2 = ZIP without prediction,
     3 = ZIP with prediction.
     """
+
     RAW = 0
     RLE = 1
     ZIP = 2
@@ -299,99 +311,100 @@ class Compression(IntEnum):
 
 class Tag(bytes, Enum):
     """Tagged blocks keys."""
-    ALPHA = b'Alph'  # Undocumented.
-    ANIMATION_EFFECTS = b'anFX'
-    ANNOTATIONS = b'Anno'
-    ARTBOARD_DATA1 = b'artb'
-    ARTBOARD_DATA2 = b'artd'
-    ARTBOARD_DATA3 = b'abdd'
-    BLACK_AND_WHITE = b'blwh'
-    BLEND_CLIPPING_ELEMENTS = b'clbl'
-    BLEND_FILL_OPACITY = b'iOpa'  # Undocumented.
-    BLEND_INTERIOR_ELEMENTS = b'infx'
-    BRIGHTNESS_AND_CONTRAST = b'brit'
-    CHANNEL_BLENDING_RESTRICTIONS_SETTING = b'brst'
-    CHANNEL_MIXER = b'mixr'
-    COLOR_BALANCE = b'blnc'
-    COLOR_LOOKUP = b'clrL'
-    COMPOSITOR_INFO = b'cinf'  # Undocumented.
-    CONTENT_GENERATOR_EXTRA_DATA = b'CgEd'
-    CURVES = b'curv'
-    EFFECTS_LAYER = b'lrFX'
-    EXPORT_SETTING1 = b'extd'  # Undocumented.
-    EXPORT_SETTING2 = b'extn'  # Undocumented.
-    EXPOSURE = b'expA'
-    FILTER_EFFECTS1 = b'FXid'
-    FILTER_EFFECTS2 = b'FEid'
-    FILTER_EFFECTS3 = b'FELS'  # Undocumented.
-    FILTER_MASK = b'FMsk'
-    FOREIGN_EFFECT_ID = b'ffxi'
-    FRAMED_GROUP = b'frgb'  # Undocumented, Frame tool in CC 2019?
-    GRADIENT_FILL_SETTING = b'GdFl'
-    GRADIENT_MAP = b'grdm'
-    HUE_SATURATION = b'hue2'
-    HUE_SATURATION_V4 = b'hue '
-    INVERT = b'nvrt'
-    KNOCKOUT_SETTING = b'knko'
-    LAYER = b'Layr'
-    LAYER_16 = b'Lr16'
-    LAYER_32 = b'Lr32'
-    LAYER_ID = b'lyid'
-    LAYER_MASK_AS_GLOBAL_MASK = b'lmgm'
-    LAYER_NAME_SOURCE_SETTING = b'lnsr'
-    LAYER_VERSION = b'lyvr'
-    LEVELS = b'levl'
-    LINKED_LAYER1 = b'lnkD'
-    LINKED_LAYER2 = b'lnk2'
-    LINKED_LAYER3 = b'lnk3'
-    LINKED_LAYER_EXTERNAL = b'lnkE'
-    METADATA_SETTING = b'shmd'
-    NESTED_SECTION_DIVIDER_SETTING = b'lsdk'
-    OBJECT_BASED_EFFECTS_LAYER_INFO = b'lfx2'
-    OBJECT_BASED_EFFECTS_LAYER_INFO_V0 = b'lmfx'  # Undocumented.
-    OBJECT_BASED_EFFECTS_LAYER_INFO_V1 = b'lfxs'  # Undocumented.
-    PATTERNS1 = b'Patt'
-    PATTERNS2 = b'Pat2'
-    PATTERNS3 = b'Pat3'
-    PATTERN_DATA = b'shpa'
-    PATTERN_FILL_SETTING = b'PtFl'
-    PHOTO_FILTER = b'phfl'
-    PIXEL_SOURCE_DATA1 = b'PxSc'
-    PIXEL_SOURCE_DATA2 = b'PxSD'
-    PLACED_LAYER1 = b'plLd'
-    PLACED_LAYER2 = b'PlLd'
-    POSTERIZE = b'post'
-    PROTECTED_SETTING = b'lspf'
-    REFERENCE_POINT = b'fxrp'
-    SAVING_MERGED_TRANSPARENCY = b'Mtrn'
-    SAVING_MERGED_TRANSPARENCY16 = b'Mt16'
-    SAVING_MERGED_TRANSPARENCY32 = b'Mt32'
-    SECTION_DIVIDER_SETTING = b'lsct'
-    SELECTIVE_COLOR = b'selc'
-    SHEET_COLOR_SETTING = b'lclr'
-    SMART_OBJECT_LAYER_DATA1 = b'SoLd'
-    SMART_OBJECT_LAYER_DATA2 = b'SoLE'
-    SOLID_COLOR_SHEET_SETTING = b'SoCo'
-    TEXT_ENGINE_DATA = b'Txt2'
-    THRESHOLD = b'thrs'
-    TRANSPARENCY_SHAPES_LAYER = b'tsly'
-    TYPE_TOOL_INFO = b'tySh'
-    TYPE_TOOL_OBJECT_SETTING = b'TySh'
-    UNICODE_LAYER_NAME = b'luni'
-    UNICODE_PATH_NAME = b'pths'
-    USER_MASK = b'LMsk'
-    USING_ALIGNED_RENDERING = b'sn2P'
-    VECTOR_MASK_AS_GLOBAL_MASK = b'vmgm'
-    VECTOR_MASK_SETTING1 = b'vmsk'
-    VECTOR_MASK_SETTING2 = b'vsms'
-    VECTOR_ORIGINATION_DATA = b'vogk'
-    VECTOR_ORIGINATION_UNKNOWN = b'vowv'
-    VECTOR_STROKE_DATA = b'vstk'
-    VECTOR_STROKE_CONTENT_DATA = b'vscg'
-    VIBRANCE = b'vibA'
+
+    ALPHA = b"Alph"  # Undocumented.
+    ANIMATION_EFFECTS = b"anFX"
+    ANNOTATIONS = b"Anno"
+    ARTBOARD_DATA1 = b"artb"
+    ARTBOARD_DATA2 = b"artd"
+    ARTBOARD_DATA3 = b"abdd"
+    BLACK_AND_WHITE = b"blwh"
+    BLEND_CLIPPING_ELEMENTS = b"clbl"
+    BLEND_FILL_OPACITY = b"iOpa"  # Undocumented.
+    BLEND_INTERIOR_ELEMENTS = b"infx"
+    BRIGHTNESS_AND_CONTRAST = b"brit"
+    CHANNEL_BLENDING_RESTRICTIONS_SETTING = b"brst"
+    CHANNEL_MIXER = b"mixr"
+    COLOR_BALANCE = b"blnc"
+    COLOR_LOOKUP = b"clrL"
+    COMPOSITOR_INFO = b"cinf"  # Undocumented.
+    CONTENT_GENERATOR_EXTRA_DATA = b"CgEd"
+    CURVES = b"curv"
+    EFFECTS_LAYER = b"lrFX"
+    EXPORT_SETTING1 = b"extd"  # Undocumented.
+    EXPORT_SETTING2 = b"extn"  # Undocumented.
+    EXPOSURE = b"expA"
+    FILTER_EFFECTS1 = b"FXid"
+    FILTER_EFFECTS2 = b"FEid"
+    FILTER_EFFECTS3 = b"FELS"  # Undocumented.
+    FILTER_MASK = b"FMsk"
+    FOREIGN_EFFECT_ID = b"ffxi"
+    FRAMED_GROUP = b"frgb"  # Undocumented, Frame tool in CC 2019?
+    GRADIENT_FILL_SETTING = b"GdFl"
+    GRADIENT_MAP = b"grdm"
+    HUE_SATURATION = b"hue2"
+    HUE_SATURATION_V4 = b"hue "
+    INVERT = b"nvrt"
+    KNOCKOUT_SETTING = b"knko"
+    LAYER = b"Layr"
+    LAYER_16 = b"Lr16"
+    LAYER_32 = b"Lr32"
+    LAYER_ID = b"lyid"
+    LAYER_MASK_AS_GLOBAL_MASK = b"lmgm"
+    LAYER_NAME_SOURCE_SETTING = b"lnsr"
+    LAYER_VERSION = b"lyvr"
+    LEVELS = b"levl"
+    LINKED_LAYER1 = b"lnkD"
+    LINKED_LAYER2 = b"lnk2"
+    LINKED_LAYER3 = b"lnk3"
+    LINKED_LAYER_EXTERNAL = b"lnkE"
+    METADATA_SETTING = b"shmd"
+    NESTED_SECTION_DIVIDER_SETTING = b"lsdk"
+    OBJECT_BASED_EFFECTS_LAYER_INFO = b"lfx2"
+    OBJECT_BASED_EFFECTS_LAYER_INFO_V0 = b"lmfx"  # Undocumented.
+    OBJECT_BASED_EFFECTS_LAYER_INFO_V1 = b"lfxs"  # Undocumented.
+    PATTERNS1 = b"Patt"
+    PATTERNS2 = b"Pat2"
+    PATTERNS3 = b"Pat3"
+    PATTERN_DATA = b"shpa"
+    PATTERN_FILL_SETTING = b"PtFl"
+    PHOTO_FILTER = b"phfl"
+    PIXEL_SOURCE_DATA1 = b"PxSc"
+    PIXEL_SOURCE_DATA2 = b"PxSD"
+    PLACED_LAYER1 = b"plLd"
+    PLACED_LAYER2 = b"PlLd"
+    POSTERIZE = b"post"
+    PROTECTED_SETTING = b"lspf"
+    REFERENCE_POINT = b"fxrp"
+    SAVING_MERGED_TRANSPARENCY = b"Mtrn"
+    SAVING_MERGED_TRANSPARENCY16 = b"Mt16"
+    SAVING_MERGED_TRANSPARENCY32 = b"Mt32"
+    SECTION_DIVIDER_SETTING = b"lsct"
+    SELECTIVE_COLOR = b"selc"
+    SHEET_COLOR_SETTING = b"lclr"
+    SMART_OBJECT_LAYER_DATA1 = b"SoLd"
+    SMART_OBJECT_LAYER_DATA2 = b"SoLE"
+    SOLID_COLOR_SHEET_SETTING = b"SoCo"
+    TEXT_ENGINE_DATA = b"Txt2"
+    THRESHOLD = b"thrs"
+    TRANSPARENCY_SHAPES_LAYER = b"tsly"
+    TYPE_TOOL_INFO = b"tySh"
+    TYPE_TOOL_OBJECT_SETTING = b"TySh"
+    UNICODE_LAYER_NAME = b"luni"
+    UNICODE_PATH_NAME = b"pths"
+    USER_MASK = b"LMsk"
+    USING_ALIGNED_RENDERING = b"sn2P"
+    VECTOR_MASK_AS_GLOBAL_MASK = b"vmgm"
+    VECTOR_MASK_SETTING1 = b"vmsk"
+    VECTOR_MASK_SETTING2 = b"vsms"
+    VECTOR_ORIGINATION_DATA = b"vogk"
+    VECTOR_ORIGINATION_UNKNOWN = b"vowv"
+    VECTOR_STROKE_DATA = b"vstk"
+    VECTOR_STROKE_CONTENT_DATA = b"vscg"
+    VIBRANCE = b"vibA"
 
     # Unknown
-    PATT = b'patt'
+    PATT = b"patt"
 
 
 TaggedBlockID = Tag  # For backward compatibility.
@@ -399,6 +412,7 @@ TaggedBlockID = Tag  # For backward compatibility.
 
 class PrintScaleStyle(IntEnum):
     """Print scale style."""
+
     CENTERED = 0
     SIZE_TO_FIT = 1
     USER_DEFINED = 2
@@ -410,46 +424,47 @@ class OSType(bytes, Enum):
     """
 
     # OS types
-    REFERENCE = b'obj '
-    DESCRIPTOR = b'Objc'
-    LIST = b'VlLs'
-    DOUBLE = b'doub'
-    UNIT_FLOAT = b'UntF'
-    UNIT_FLOATS = b'UnFl'  # Undocumented
-    STRING = b'TEXT'
-    ENUMERATED = b'enum'
-    INTEGER = b'long'
-    LARGE_INTEGER = b'comp'
-    BOOLEAN = b'bool'
-    GLOBAL_OBJECT = b'GlbO'
-    CLASS1 = b'type'
-    CLASS2 = b'GlbC'
-    ALIAS = b'alis'
-    RAW_DATA = b'tdta'
-    OBJECT_ARRAY = b'ObAr'  # Undocumented
-    PATH = b'Pth '  # Undocumented
+    REFERENCE = b"obj "
+    DESCRIPTOR = b"Objc"
+    LIST = b"VlLs"
+    DOUBLE = b"doub"
+    UNIT_FLOAT = b"UntF"
+    UNIT_FLOATS = b"UnFl"  # Undocumented
+    STRING = b"TEXT"
+    ENUMERATED = b"enum"
+    INTEGER = b"long"
+    LARGE_INTEGER = b"comp"
+    BOOLEAN = b"bool"
+    GLOBAL_OBJECT = b"GlbO"
+    CLASS1 = b"type"
+    CLASS2 = b"GlbC"
+    ALIAS = b"alis"
+    RAW_DATA = b"tdta"
+    OBJECT_ARRAY = b"ObAr"  # Undocumented
+    PATH = b"Pth "  # Undocumented
 
     # Reference OS types
-    PROPERTY = b'prop'
-    CLASS3 = b'Clss'
-    ENUMERATED_REFERENCE = b'Enmr'
-    OFFSET = b'rele'
-    IDENTIFIER = b'Idnt'
-    INDEX = b'indx'
-    NAME = b'name'
+    PROPERTY = b"prop"
+    CLASS3 = b"Clss"
+    ENUMERATED_REFERENCE = b"Enmr"
+    OFFSET = b"rele"
+    IDENTIFIER = b"Idnt"
+    INDEX = b"indx"
+    NAME = b"name"
 
 
 class EffectOSType(bytes, Enum):
     """
     OS Type keys for Layer Effects.
     """
-    COMMON_STATE = b'cmnS'
-    DROP_SHADOW = b'dsdw'
-    INNER_SHADOW = b'isdw'
-    OUTER_GLOW = b'oglw'
-    INNER_GLOW = b'iglw'
-    BEVEL = b'bevl'
-    SOLID_FILL = b'sofi'
+
+    COMMON_STATE = b"cmnS"
+    DROP_SHADOW = b"dsdw"
+    INNER_SHADOW = b"isdw"
+    OUTER_GLOW = b"oglw"
+    INNER_GLOW = b"iglw"
+    BEVEL = b"bevl"
+    SOLID_FILL = b"sofi"
 
 
 class PathResourceID(IntEnum):
@@ -487,3 +502,7 @@ class SheetColorType(IntEnum):
     BLUE = 5
     VIOLET = 6
     GRAY = 7
+    SEAFOAM = 8
+    INDIGO = 9
+    MAGENTA = 10
+    FUSCHIA = 11
