@@ -2,9 +2,11 @@
 Adjustment layer structure.
 """
 from __future__ import absolute_import, unicode_literals
-import attr
+
 import logging
 
+import attr
+
 from psd_tools.constants import Tag
 from psd_tools.psd.base import (
     BaseElement,
@@ -13,26 +15,34 @@ from psd_tools.psd.base import (
     ShortIntegerElement,
 )
 from psd_tools.psd.descriptor import DescriptorBlock, DescriptorBlock2
-from psd_tools.validators import in_
 from psd_tools.utils import (
-    read_fmt, write_fmt, is_readable, write_bytes, read_unicode_string,
-    write_unicode_string, write_padding, new_registry
+    is_readable,
+    new_registry,
+    read_fmt,
+    read_unicode_string,
+    write_bytes,
+    write_fmt,
+    write_padding,
+    write_unicode_string,
 )
+from psd_tools.validators import in_
 
 logger = logging.getLogger(__name__)
 
 ADJUSTMENT_TYPES, register = new_registry()
 
-ADJUSTMENT_TYPES.update({
-    Tag.BLACK_AND_WHITE: DescriptorBlock,
-    Tag.GRADIENT_FILL_SETTING: DescriptorBlock,
-    Tag.INVERT: EmptyElement,
-    Tag.PATTERN_FILL_SETTING: DescriptorBlock,
-    Tag.POSTERIZE: ShortIntegerElement,
-    Tag.SOLID_COLOR_SHEET_SETTING: DescriptorBlock,
-    Tag.THRESHOLD: ShortIntegerElement,
-    Tag.VIBRANCE: DescriptorBlock,
-})
+ADJUSTMENT_TYPES.update(
+    {
+        Tag.BLACK_AND_WHITE: DescriptorBlock,
+        Tag.GRADIENT_FILL_SETTING: DescriptorBlock,
+        Tag.INVERT: EmptyElement,
+        Tag.PATTERN_FILL_SETTING: DescriptorBlock,
+        Tag.POSTERIZE: ShortIntegerElement,
+        Tag.SOLID_COLOR_SHEET_SETTING: DescriptorBlock,
+        Tag.THRESHOLD: ShortIntegerElement,
+        Tag.VIBRANCE: DescriptorBlock,
+    }
+)
 
 
 @register(Tag.BRIGHTNESS_AND_CONTRAST)
@@ -46,6 +56,7 @@ class BrightnessContrast(BaseElement):
     .. py:attribute:: mean
     .. py:attribute:: lab_only
     """
+
     brightness = attr.ib(default=0, type=int)
     contrast = attr.ib(default=0, type=int)
     mean = attr.ib(default=0, type=int)
@@ -53,10 +64,10 @@ class BrightnessContrast(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(*read_fmt('3HBx', fp))
+        return cls(*read_fmt("3HBx", fp))
 
     def write(self, fp, **kwargs):
-        return write_fmt(fp, '3HBx', *attr.astuple(self))
+        return write_fmt(fp, "3HBx", *attr.astuple(self))
 
 
 @register(Tag.COLOR_BALANCE)
@@ -70,24 +81,25 @@ class ColorBalance(BaseElement):
     .. py:attribute:: highlights
     .. py:attribute:: luminosity
     """
-    shadows = attr.ib(default=(0, ) * 3, type=tuple)
-    midtones = attr.ib(default=(0, ) * 3, type=tuple)
-    highlights = attr.ib(default=(0, ) * 3, type=tuple)
+
+    shadows = attr.ib(default=(0,) * 3, type=tuple)
+    midtones = attr.ib(default=(0,) * 3, type=tuple)
+    highlights = attr.ib(default=(0,) * 3, type=tuple)
     luminosity = attr.ib(default=False, type=bool)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        shadows = read_fmt('3h', fp)
-        midtones = read_fmt('3h', fp)
-        highlights = read_fmt('3h', fp)
-        luminosity = read_fmt('B', fp)[0]
+        shadows = read_fmt("3h", fp)
+        midtones = read_fmt("3h", fp)
+        highlights = read_fmt("3h", fp)
+        luminosity = read_fmt("B", fp)[0]
         return cls(shadows, midtones, highlights, luminosity)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, '3h', *self.shadows)
-        written += write_fmt(fp, '3h', *self.midtones)
-        written += write_fmt(fp, '3h', *self.highlights)
-        written += write_fmt(fp, 'B', self.luminosity)
+        written = write_fmt(fp, "3h", *self.shadows)
+        written += write_fmt(fp, "3h", *self.midtones)
+        written += write_fmt(fp, "3h", *self.highlights)
+        written += write_fmt(fp, "B", self.luminosity)
         written += write_padding(fp, written, 4)
         return written
 
@@ -104,13 +116,11 @@ class ColorLookup(DescriptorBlock2):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version, data_version = read_fmt('HI', fp)
-        return cls(
-            version=version, data_version=data_version, **cls._read_body(fp)
-        )
+        version, data_version = read_fmt("HI", fp)
+        return cls(version=version, data_version=data_version, **cls._read_body(fp))
 
     def write(self, fp, padding=4, **kwargs):
-        written = write_fmt(fp, 'HI', self.version, self.data_version)
+        written = write_fmt(fp, "HI", self.version, self.data_version)
         written += self._write_body(fp)
         written += write_padding(fp, written, padding)
         return written
@@ -126,21 +136,22 @@ class ChannelMixer(BaseElement):
     .. py:attribute:: monochrome
     .. py:attribute:: data
     """
-    version = attr.ib(default=1, type=int, validator=in_((1, )))
+
+    version = attr.ib(default=1, type=int, validator=in_((1,)))
     monochrome = attr.ib(default=0, type=int)
     data = attr.ib(factory=list, converter=list)
-    unknown = attr.ib(default=b'', type=bytes, repr=False)
+    unknown = attr.ib(default=b"", type=bytes, repr=False)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version, monochrome = read_fmt('2H', fp)
-        data = list(read_fmt('5h', fp))
+        version, monochrome = read_fmt("2H", fp)
+        data = list(read_fmt("5h", fp))
         unknown = fp.read()
         return cls(version, monochrome, data, unknown)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, '2H', self.version, self.monochrome)
-        written += write_fmt(fp, '5h', *self.data)
+        written = write_fmt(fp, "2H", self.version, self.monochrome)
+        written += write_fmt(fp, "5h", *self.data)
         written += write_bytes(fp, self.unknown)
         return written
 
@@ -157,6 +168,7 @@ class Curves(BaseElement):
     .. py:attribute:: data
     .. py:attribute:: extra
     """
+
     is_map = attr.ib(default=False, type=bool, converter=bool)
     version = attr.ib(default=0, type=int)
     count_map = attr.ib(default=0, type=int)
@@ -166,25 +178,25 @@ class Curves(BaseElement):
     @classmethod
     def read(cls, fp, **kwargs):
         # NOTE: This is highly experimental and unstable.
-        is_map, version, count_map = read_fmt('BHI', fp)
-        assert version in (1, 4), 'Invalid version %d' % (version)
+        is_map, version, count_map = read_fmt("BHI", fp)
+        assert version in (1, 4), "Invalid version %d" % (version)
 
         if version == 1:
-            count = bin(count_map).count('1')  # Bitmap = channel index?
+            count = bin(count_map).count("1")  # Bitmap = channel index?
         else:
             count = count_map
 
         if is_map:
             # This lookup format is never documented.
-            data = [list(read_fmt('256B', fp)) for _ in range(count)]
+            data = [list(read_fmt("256B", fp)) for _ in range(count)]
         else:
             data = []
             for _ in range(count):
-                point_count = read_fmt('H', fp)[0]
-                assert 2 <= point_count and point_count <= 19, (
-                    'Curves point count not in [2, 19]'
-                )
-                points = [read_fmt('2H', fp) for i in range(point_count)]
+                point_count = read_fmt("H", fp)[0]
+                assert (
+                    2 <= point_count and point_count <= 19
+                ), "Curves point count not in [2, 19]"
+                points = [read_fmt("2H", fp) for i in range(point_count)]
                 data.append(points)
 
         extra = None
@@ -192,20 +204,18 @@ class Curves(BaseElement):
             try:
                 extra = CurvesExtraMarker.read(fp, is_map=is_map)
             except AssertionError:
-                logger.warning('Failed to read CurvesExtraMarker')
+                logger.warning("Failed to read CurvesExtraMarker")
 
         return cls(is_map, version, count_map, data, extra)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(
-            fp, 'BHI', self.is_map, self.version, self.count_map
-        )
+        written = write_fmt(fp, "BHI", self.is_map, self.version, self.count_map)
         if self.is_map:
-            written += sum(write_fmt(fp, '256B', *item) for item in self.data)
+            written += sum(write_fmt(fp, "256B", *item) for item in self.data)
         else:
             for points in self.data:
-                written += write_fmt(fp, 'H', len(points))
-                written += sum(write_fmt(fp, '2H', *item) for item in points)
+                written += write_fmt(fp, "H", len(points))
+                written += sum(write_fmt(fp, "2H", *item) for item in points)
 
         if self.extra is not None:
             written += self.extra.write(fp)
@@ -221,19 +231,20 @@ class CurvesExtraMarker(ListElement):
 
     .. py:attribute:: version
     """
+
     version = attr.ib(default=4, type=int, validator=in_((3, 4)))
 
     @classmethod
     def read(cls, fp, **kwargs):
-        signature, version, count = read_fmt('4sHI', fp)
-        assert signature == b'Crv ', 'Invalid signature %r' % (signature)
+        signature, version, count = read_fmt("4sHI", fp)
+        assert signature == b"Crv ", "Invalid signature %r" % (signature)
         items = []
-        for i in range(count):
+        for _ in range(count):
             items.append(CurvesExtraItem.read(fp, **kwargs))
         return cls(version=version, items=items)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, '4sHI', b'Crv ', self.version, len(self))
+        written = write_fmt(fp, "4sHI", b"Crv ", self.version, len(self))
         written += sum(item.write(fp) for item in self)
         return written
 
@@ -246,26 +257,27 @@ class CurvesExtraItem(BaseElement):
     .. py:attribute:: channel_id
     .. py:attribute:: points
     """
+
     channel_id = attr.ib(default=0, type=int)
     points = attr.ib(factory=list, converter=list)
 
     @classmethod
     def read(cls, fp, is_map=False, **kwargs):
         if is_map:
-            channel_id = read_fmt('H', fp)[0]
-            points = list(read_fmt('256B', fp))
+            channel_id = read_fmt("H", fp)[0]
+            points = list(read_fmt("256B", fp))
         else:
-            channel_id, point_count = read_fmt('2H', fp)
-            points = [read_fmt('2H', fp) for c in range(point_count)]
+            channel_id, point_count = read_fmt("2H", fp)
+            points = [read_fmt("2H", fp) for c in range(point_count)]
         return cls(channel_id, points)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'H', self.channel_id)
+        written = write_fmt(fp, "H", self.channel_id)
         if len(self.points) > 0 and isinstance(self.points[0], int):
-            written += write_fmt(fp, '256B', *self.points)
+            written += write_fmt(fp, "256B", *self.points)
         else:
-            written += write_fmt(fp, 'H', len(self.points))
-            written += sum(write_fmt(fp, '2H', *p) for p in self.points)
+            written += write_fmt(fp, "H", len(self.points))
+            written += sum(write_fmt(fp, "2H", *p) for p in self.points)
         return written
 
 
@@ -293,16 +305,36 @@ class GradientMap(BaseElement):
     .. py:attribute:: minimum_color
     .. py:attribute:: maximum_color
     """
-    version = attr.ib(default=1, type=int, validator=in_((1, 3, )))
+
+    version = attr.ib(
+        default=1,
+        type=int,
+        validator=in_(
+            (
+                1,
+                3,
+            )
+        ),
+    )
     is_reversed = attr.ib(default=0, type=int)
     is_dithered = attr.ib(default=0, type=int)
-    name = attr.ib(default='', type=str)
-    method = attr.ib(default=b'Gcls', type=bytes, validator=in_((b'Gcls', b'Lnr ', b'Perc',)))
+    name = attr.ib(default="", type=str)
+    method = attr.ib(
+        default=b"Gcls",
+        type=bytes,
+        validator=in_(
+            (
+                b"Gcls",
+                b"Lnr ",
+                b"Perc",
+            )
+        ),
+    )
     color_stops = attr.ib(factory=list, converter=list)
     transparency_stops = attr.ib(factory=list, converter=list)
-    expansion = attr.ib(default=2, type=int, validator=in_((2, )))
+    expansion = attr.ib(default=2, type=int, validator=in_((2,)))
     interpolation = attr.ib(default=0, type=int)
-    length = attr.ib(default=32, type=int, validator=in_((32, )))
+    length = attr.ib(default=32, type=int, validator=in_((32,)))
     mode = attr.ib(default=0, type=int)
     random_seed = attr.ib(default=0, type=int)
     show_transparency = attr.ib(default=0, type=int)
@@ -314,47 +346,67 @@ class GradientMap(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version, is_reversed, is_dithered = read_fmt('H2B', fp)
-        assert version in (1, 3), 'Invalid version %s' % (version)
-        method = read_fmt('4s', fp)[0] if version == 3 else b'Gcls'
+        version, is_reversed, is_dithered = read_fmt("H2B", fp)
+        assert version in (1, 3), "Invalid version %s" % (version)
+        method = read_fmt("4s", fp)[0] if version == 3 else b"Gcls"
         name = read_unicode_string(fp)
-        count = read_fmt('H', fp)[0]
+        count = read_fmt("H", fp)[0]
         color_stops = [ColorStop.read(fp) for _ in range(count)]
-        count = read_fmt('H', fp)[0]
+        count = read_fmt("H", fp)[0]
         transparency_stops = [TransparencyStop.read(fp) for _ in range(count)]
-        expansion, interpolation, length, mode = read_fmt('4H', fp)
-        assert expansion == 2, 'Invalid expansion %d' % (expansion)
-        random_seed, show_transparency, use_vector_color = read_fmt('I2H', fp)
-        roughness, color_model = read_fmt('IH', fp)
-        minimum_color = read_fmt('4H', fp)
-        maximum_color = read_fmt('4H', fp)
-        read_fmt('2x', fp)  # Dummy?
+        expansion, interpolation, length, mode = read_fmt("4H", fp)
+        assert expansion == 2, "Invalid expansion %d" % (expansion)
+        random_seed, show_transparency, use_vector_color = read_fmt("I2H", fp)
+        roughness, color_model = read_fmt("IH", fp)
+        minimum_color = read_fmt("4H", fp)
+        maximum_color = read_fmt("4H", fp)
+        read_fmt("2x", fp)  # Dummy?
         return cls(
-            version, is_reversed, is_dithered, name, method, color_stops,
-            transparency_stops, expansion, interpolation, length, mode,
-            random_seed, show_transparency, use_vector_color, roughness,
-            color_model, minimum_color, maximum_color
+            version,
+            is_reversed,
+            is_dithered,
+            name,
+            method,
+            color_stops,
+            transparency_stops,
+            expansion,
+            interpolation,
+            length,
+            mode,
+            random_seed,
+            show_transparency,
+            use_vector_color,
+            roughness,
+            color_model,
+            minimum_color,
+            maximum_color,
         )
 
     def write(self, fp, **kwargs):
-        written = write_fmt(
-            fp, 'H2B', self.version, self.is_reversed, self.is_dithered
-        )
+        written = write_fmt(fp, "H2B", self.version, self.is_reversed, self.is_dithered)
         if self.version == 3:
-            written += write_fmt(fp, '4s', self.method)
+            written += write_fmt(fp, "4s", self.method)
         written += write_unicode_string(fp, self.name)
-        written += write_fmt(fp, 'H', len(self.color_stops))
+        written += write_fmt(fp, "H", len(self.color_stops))
         written += sum(stop.write(fp) for stop in self.color_stops)
-        written += write_fmt(fp, 'H', len(self.transparency_stops))
+        written += write_fmt(fp, "H", len(self.transparency_stops))
         written += sum(stop.write(fp) for stop in self.transparency_stops)
         written += write_fmt(
-            fp, '4HI2HIH', self.expansion, self.interpolation, self.length,
-            self.mode, self.random_seed, self.show_transparency,
-            self.use_vector_color, self.roughness, self.color_model
+            fp,
+            "4HI2HIH",
+            self.expansion,
+            self.interpolation,
+            self.length,
+            self.mode,
+            self.random_seed,
+            self.show_transparency,
+            self.use_vector_color,
+            self.roughness,
+            self.color_model,
         )
-        written += write_fmt(fp, '4H', *self.minimum_color)
-        written += write_fmt(fp, '4H', *self.maximum_color)
-        written += write_fmt(fp, '2x')
+        written += write_fmt(fp, "4H", *self.minimum_color)
+        written += write_fmt(fp, "4H", *self.maximum_color)
+        written += write_fmt(fp, "2x")
         written += write_padding(fp, written, 4)
         return written
 
@@ -369,6 +421,7 @@ class ColorStop(BaseElement):
     .. py:attribute:: mode
     .. py:attribute:: color
     """
+
     location = attr.ib(default=0, type=int)
     midpoint = attr.ib(default=0, type=int)
     mode = attr.ib(default=0, type=int)
@@ -376,13 +429,13 @@ class ColorStop(BaseElement):
 
     @classmethod
     def read(cls, fp):
-        location, midpoint, mode = read_fmt('2IH', fp)
-        color = read_fmt('4H2x', fp)
+        location, midpoint, mode = read_fmt("2IH", fp)
+        color = read_fmt("4H2x", fp)
         return cls(location, midpoint, mode, color)
 
     def write(self, fp):
         return write_fmt(
-            fp, '2I5H2x', self.location, self.midpoint, self.mode, *self.color
+            fp, "2I5H2x", self.location, self.midpoint, self.mode, *self.color
         )
 
 
@@ -395,16 +448,17 @@ class TransparencyStop(BaseElement):
     .. py:attribute:: midpoint
     .. py:attribute:: opacity
     """
+
     location = attr.ib(default=0, type=int)
     midpoint = attr.ib(default=0, type=int)
     opacity = attr.ib(default=0, type=int)
 
     @classmethod
     def read(cls, fp):
-        return cls(*read_fmt('2IH', fp))
+        return cls(*read_fmt("2IH", fp))
 
     def write(self, fp):
-        return write_fmt(fp, '2IH', *attr.astuple(self))
+        return write_fmt(fp, "2IH", *attr.astuple(self))
 
 
 @register(Tag.EXPOSURE)
@@ -418,17 +472,18 @@ class Exposure(BaseElement):
     .. py:attribute:: offset
     .. py:attribute:: gamma
     """
+
     version = attr.ib(default=0, type=int)
-    exposure = attr.ib(default=0., type=float)
-    offset = attr.ib(default=0., type=float)
-    gamma = attr.ib(default=0., type=float)
+    exposure = attr.ib(default=0.0, type=float)
+    offset = attr.ib(default=0.0, type=float)
+    gamma = attr.ib(default=0.0, type=float)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        return cls(*read_fmt('H3f', fp))
+        return cls(*read_fmt("H3f", fp))
 
     def write(self, fp, padding=4, **kwargs):
-        written = write_fmt(fp, 'H3f', *attr.astuple(self))
+        written = write_fmt(fp, "H3f", *attr.astuple(self))
         written += write_padding(fp, written, padding)
         return written
 
@@ -446,6 +501,7 @@ class HueSaturation(BaseElement):
     .. py:attribute:: master
     .. py:attribute:: items
     """
+
     version = attr.ib(default=2, type=int)
     enable = attr.ib(default=1, type=int)
     colorization = attr.ib(default=(0, 0, 0), type=tuple)
@@ -454,24 +510,24 @@ class HueSaturation(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version, enable = read_fmt('HBx', fp)
-        assert version == 2, 'Invalid version %d' % (version)
-        colorization = read_fmt('3h', fp)
-        master = read_fmt('3h', fp)
+        version, enable = read_fmt("HBx", fp)
+        assert version == 2, "Invalid version %d" % (version)
+        colorization = read_fmt("3h", fp)
+        master = read_fmt("3h", fp)
         items = []
         for _ in range(6):
-            range_values = read_fmt('4h', fp)
-            settings_values = read_fmt('3h', fp)
+            range_values = read_fmt("4h", fp)
+            settings_values = read_fmt("3h", fp)
             items.append([range_values, settings_values])
         return cls(version, enable, colorization, master, items)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'HBx', self.version, self.enable)
-        written += write_fmt(fp, '3h', *self.colorization)
-        written += write_fmt(fp, '3h', *self.master)
+        written = write_fmt(fp, "HBx", self.version, self.enable)
+        written += write_fmt(fp, "3h", *self.colorization)
+        written += write_fmt(fp, "3h", *self.master)
         for item in self.items:
-            written += write_fmt(fp, '4h', *item[0])
-            written += write_fmt(fp, '3h', *item[1])
+            written += write_fmt(fp, "4h", *item[0])
+            written += write_fmt(fp, "3h", *item[1])
         written += write_padding(fp, written, 4)
         return written
 
@@ -491,35 +547,34 @@ class Levels(ListElement):
 
         Version of the extra field.
     """
-    version = attr.ib(default=0, type=int, validator=in_((2, )))
+
+    version = attr.ib(default=0, type=int, validator=in_((2,)))
     extra_version = attr.ib(default=None)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version = read_fmt('H', fp)[0]
-        assert version == 2, 'Invalid version %d' % (version)
+        version = read_fmt("H", fp)[0]
+        assert version == 2, "Invalid version %d" % (version)
         items = [LevelRecord.read(fp) for _ in range(29)]
 
         extra_version = None
         if is_readable(fp, 6):
-            signature, extra_version = read_fmt('4sH', fp)
-            assert signature == b'Lvls', 'Invalid signature %r' % (signature)
-            assert extra_version == 3, 'Invalid extra version %d' % (
-                extra_version
-            )
-            count = read_fmt('H', fp)[0]
+            signature, extra_version = read_fmt("4sH", fp)
+            assert signature == b"Lvls", "Invalid signature %r" % (signature)
+            assert extra_version == 3, "Invalid extra version %d" % (extra_version)
+            count = read_fmt("H", fp)[0]
             items += [LevelRecord.read(fp) for _ in range(count - 29)]
 
         return cls(version=version, extra_version=extra_version, items=items)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'H', self.version)
+        written = write_fmt(fp, "H", self.version)
         for index in range(29):
             written += self[index].write(fp)
 
         if self.extra_version is not None:
-            written += write_fmt(fp, '4sH', b'Lvls', self.extra_version)
-            written += write_fmt(fp, 'H', len(self))
+            written += write_fmt(fp, "4sH", b"Lvls", self.extra_version)
+            written += write_fmt(fp, "H", len(self))
             for index in range(29, len(self)):
                 written += self[index].write(fp)
 
@@ -553,6 +608,7 @@ class LevelRecord(BaseElement):
         Gamma. Short integer from 10...999 representing 0.1...9.99. Applied
         to all image data.
     """
+
     input_floor = attr.ib(default=0, type=int)
     input_ceiling = attr.ib(default=0, type=int)
     output_floor = attr.ib(default=0, type=int)
@@ -561,10 +617,10 @@ class LevelRecord(BaseElement):
 
     @classmethod
     def read(cls, fp):
-        return cls(*read_fmt('5H', fp))
+        return cls(*read_fmt("5H", fp))
 
     def write(self, fp):
-        return write_fmt(fp, '5H', *attr.astuple(self))
+        return write_fmt(fp, "5H", *attr.astuple(self))
 
 
 @register(Tag.PHOTO_FILTER)
@@ -580,6 +636,7 @@ class PhotoFilter(BaseElement):
     .. py:attribute:: density
     .. py:attribute:: luminosity
     """
+
     version = attr.ib(default=0, type=int, validator=in_((2, 3)))
     xyz = attr.ib(default=(0, 0, 0), type=tuple)
     color_space = attr.ib(default=None)
@@ -589,30 +646,26 @@ class PhotoFilter(BaseElement):
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version = read_fmt('H', fp)[0]
-        assert version in (2, 3), 'Invalid version %d' % (version)
+        version = read_fmt("H", fp)[0]
+        assert version in (2, 3), "Invalid version %d" % (version)
         if version == 3:
-            xyz = read_fmt('3I', fp)
+            xyz = read_fmt("3I", fp)
             color_space = None
             color_components = None
         else:
             xyz = None
-            color_space = read_fmt('H', fp)[0]
-            color_components = read_fmt('4H', fp)
-        density, luminosity = read_fmt('IB', fp)
-        return cls(
-            version, xyz, color_space, color_components, density, luminosity
-        )
+            color_space = read_fmt("H", fp)[0]
+            color_components = read_fmt("4H", fp)
+        density, luminosity = read_fmt("IB", fp)
+        return cls(version, xyz, color_space, color_components, density, luminosity)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, 'H', self.version)
+        written = write_fmt(fp, "H", self.version)
         if self.version == 3:
-            written += write_fmt(fp, '3I', *self.xyz)
+            written += write_fmt(fp, "3I", *self.xyz)
         else:
-            written += write_fmt(
-                fp, 'H4H', self.color_space, *self.color_components
-            )
-        written += write_fmt(fp, 'IB', self.density, self.luminosity)
+            written += write_fmt(fp, "H4H", self.color_space, *self.color_components)
+        written += write_fmt(fp, "IB", self.density, self.luminosity)
         written += write_padding(fp, written, 4)
         return written
 
@@ -627,18 +680,19 @@ class SelectiveColor(BaseElement):
     .. py:attribute:: method
     .. py:attribute:: data
     """
-    version = attr.ib(default=1, type=int, validator=in_((1, )))
+
+    version = attr.ib(default=1, type=int, validator=in_((1,)))
     method = attr.ib(default=0, type=int)
     data = attr.ib(factory=list, converter=list)
 
     @classmethod
     def read(cls, fp, **kwargs):
-        version, method = read_fmt('2H', fp)
-        data = [read_fmt('4h', fp) for i in range(10)]
+        version, method = read_fmt("2H", fp)
+        data = [read_fmt("4h", fp) for i in range(10)]
         return cls(version, method, data)
 
     def write(self, fp, **kwargs):
-        written = write_fmt(fp, '2H', self.version, self.method)
+        written = write_fmt(fp, "2H", self.version, self.method)
         for plate in self.data:
-            written += write_fmt(fp, '4h', *plate)
+            written += write_fmt(fp, "4h", *plate)
         return written
